@@ -299,6 +299,7 @@ class Parser(ABC):
         http_ignore_tls: bool = False,
         use_annotated: bool = False,
         use_non_positive_negative_number_constrained_types: bool = False,
+        original_field_name_delimiter: Optional[str] = None,
     ):
         self.data_type_manager: DataTypeManager = data_type_manager_type(
             target_python_version,
@@ -376,6 +377,7 @@ class Parser(ABC):
             snake_case_field=snake_case_field,
             custom_class_name_generator=custom_class_name_generator,
             base_path=self.base_path,
+            original_field_name_delimiter=original_field_name_delimiter,
         )
         self.class_name: Optional[str] = class_name
         self.wrap_string_literal: Optional[bool] = wrap_string_literal
